//::///////////////////////////////////////////////
//:: Smouldering Ray
//:: [kc_s2_smouldering_ray.nss]
//:: Copyright (c) 2007 Kris C.
//:://////////////////////////////////////////////
/*
	If the caster succeeds at a ranged touch attack
	the target takes 3d6 damage.
*/
//:://////////////////////////////////////////////
//:: Created By: Kris C.
//:: Created On: July 10, 2007
//:: Updated By: Lavallet (Ivan K.)
//:: Updated On: September 16, 2018
//:://////////////////////////////////////////////

#include "x0_i0_spells"
#include "x2_inc_spellhook"
#include "nwn2_inc_spells"
#include "kprc_inc_sneakattack"

const int SPELLABILITY_FIREGNOME_SMOULDERING_RAY = 9001;

void main()
{
	if (!X2PreSpellCastCode())
	{
		return;
	}

	// Declaring the major variables.
	object oTarget = GetSpellTargetObject();

	if (spellsIsTarget(oTarget, SPELL_TARGET_STANDARDHOSTILE, OBJECT_SELF))
	{
		// Fire cast spell at event for the specified target.
		SignalEvent(oTarget, EventSpellCastAt(OBJECT_SELF, SPELLABILITY_FIREGNOME_SMOULDERING_RAY));
		int nTouch = TouchAttackRanged(oTarget);

		if (nTouch != TOUCH_ATTACK_RESULT_MISS)
		{
			// Make a SR Check.
			if(!MyResistSpell(OBJECT_SELF, oTarget))
			{
				// Enter the Metamagic conditions.
				int nDam = d6(3);
				nDam = ApplyMetamagicVariableMods(nDam, 18);

				if (nTouch == TOUCH_ATTACK_RESULT_CRITICAL && !GetIsImmune(oTarget, IMMUNITY_TYPE_CRITICAL_HIT))
				{
					nDam = d6(6);
					nDam = ApplyMetamagicVariableMods(nDam, 36);
				}

				nDam += EvaluateSneakAttack(oTarget, OBJECT_SELF);

				// Set damage effect
				effect eDam = EffectDamage(nDam, DAMAGE_TYPE_FIRE);
				effect eVis = EffectVisualEffect(VFX_HIT_SPELL_FIRE);

				// Apply the VFX impact and damage effect
				ApplyEffectToObject(DURATION_TYPE_INSTANT, eVis, oTarget);
				ApplyEffectToObject(DURATION_TYPE_INSTANT, eDam, oTarget);
			}
		}
	}

	effect eRay = EffectBeam(VFX_BEAM_FIRE, OBJECT_SELF, BODY_NODE_HAND);
	ApplyEffectToObject(DURATION_TYPE_TEMPORARY, eRay, oTarget, 1.7);
}